@@ -1,14 +1,24 @@
 #' Check if cache table is indexed
 #'
-#' Tested only with SQLite and MySql. May work with other drivers. Used to check if given cache table is indexed (if created with any version of `tidywikidatar` before 0.6, they are probably not indexed and less efficient).
+#' Tested only with SQLite and MySql. May work with other drivers. Used to check
+#' if given cache table is indexed (if created with any version of
+#' `tidywikidatar` before 0.6, they are probably not indexed and less
+#' efficient).
 #'
-#' @param table_name Name of the table in the database. If given, it takes precedence over other parameters.
-#' @param show_details Logical, defaults to FALSE. If FALSE, return a logical vector of length one (TRUE if the table was indexed, FALSE if it was not). If TRUE, returns a data frame with more details about the index.
+#' @param table_name Name of the table in the database. If given, it takes
+#'   precedence over other parameters.
+#' @param show_details Logical, defaults to `FALSE`. If `FALSE`, return a
+#'   logical vector of length one (`TRUE` if the table was indexed, `FALSE` if
+#'   it was not). If `TRUE`, returns a data frame with more details about the
+#'   index.
 #'
 #' @inheritParams tw_get_cache_table_name
 #' @inheritParams tw_get
 #'
-#' @return If `show_details` is set to FALSE, return a logical vector of length one (TRUE if the table was indexed, FALSE if it was not). If `show_details` is set to TRUE, returns a data frame with more details about the index.
+#' @return If `show_details` is set to `FALSE`, return a logical vector of
+#'   length one (`TRUE` if the table was indexed, `FALSE` if it was not). If
+#'   `show_details` is set to `TRUE`, returns a data frame with more details
+#'   about the index.
 #' @export
 #'
 #' @examples
@@ -24,15 +34,17 @@
 #'
 #'   tw_check_cache_index()
 #' }
-tw_check_cache_index <- function(table_name = NULL,
-                                 type = "item",
-                                 show_details = FALSE,
-                                 language = tidywikidatar::tw_get_language(),
-                                 response_language = tidywikidatar::tw_get_language(),
-                                 cache = NULL,
-                                 cache_connection = NULL,
-                                 disconnect_db = TRUE) {
-  if (is.null(table_name) == TRUE) {
+tw_check_cache_index <- function(
+  table_name = NULL,
+  type = "item",
+  show_details = FALSE,
+  language = tidywikidatar::tw_get_language(),
+  response_language = tidywikidatar::tw_get_language(),
+  cache = NULL,
+  cache_connection = NULL,
+  disconnect_db = TRUE
+) {
+  if (is.null(table_name)) {
     table_name <- tw_get_cache_table_name(
       type = type,
       language = language,
@@ -40,7 +52,10 @@ tw_check_cache_index <- function(table_name = NULL,
     )
   }
 
-  if (stringr::str_starts(string = type, pattern = "search") & stringr::str_detect(string = language, pattern = "_", negate = TRUE)) {
+  if (
+    stringr::str_starts(string = type, pattern = "search") &
+      stringr::str_detect(string = language, pattern = "_", negate = TRUE)
+  ) {
     language <- stringr::str_c(language, "_", response_language)
   }
 
@@ -67,7 +82,8 @@ tw_check_cache_index <- function(table_name = NULL,
   if (inherits(x = driver, "SQLiteConnection")) {
     db_no_pool <- pool::poolCheckout(db)
 
-    statement <- glue::glue_sql("PRAGMA INDEX_LIST({`table_name`});",
+    statement <- glue::glue_sql(
+      "PRAGMA INDEX_LIST({`table_name`});",
       table_name = table_name,
       .con = db_no_pool
     )
@@ -81,16 +97,17 @@ tw_check_cache_index <- function(table_name = NULL,
 
     pool::poolReturn(db_no_pool)
 
-    if (show_details == TRUE) {
+    if (show_details) {
       output <- tibble::as_tibble(index_odbc_result_fetched)
     } else {
       output <- nrow(tibble::as_tibble(index_odbc_result_fetched)) > 0
     }
   } else {
-    if (show_details == TRUE) {
+    if (show_details) {
       db_no_pool <- pool::poolCheckout(db)
 
-      statement <- glue::glue_sql("SHOW INDEX FROM {`table_name`}",
+      statement <- glue::glue_sql(
+        "SHOW INDEX FROM {`table_name`}",
         table_name = table_name,
         .con = db_no_pool
       )
@@ -105,7 +122,8 @@ tw_check_cache_index <- function(table_name = NULL,
 
       output <- tibble::as_tibble(index_odbc_result_fetched)
     } else {
-      statement <- glue::glue_sql("SHOW INDEX FROM {`table_name`}",
+      statement <- glue::glue_sql(
+        "SHOW INDEX FROM {`table_name`}",
         table_name = table_name,
         .con = db
       )
@@ -127,21 +145,29 @@ tw_check_cache_index <- function(table_name = NULL,
 }
 
 
-
 #' Add index to caching table for search queries for increased speed
 #'
 #' Tested only with SQLite and MySql. May work with other drivers.
 #'
-#' To ensure smooth functioning, the search column in the cache table is transformed into a column of type `varchar` and length 255.
+#' To ensure smooth functioning, the search column in the cache table is
+#' transformed into a column of type `varchar` and length 255.
 #'
-#' @param table_name Name of the table in the database. If given, it takes precedence over other parameters.
-#' @param check_first Logical, defaults to TRUE. If TRUE, then before executing anything on the database it checks if the given table has already been indexed. If it has, it does nothing and returns only an informative message.
-#' @param show_details Logical, defaults to FALSE. If FALSE, return the function adds the index to the database, but does not return anything. If TRUE, returns a data frame with more details about the index.
+#' @param table_name Name of the table in the database. If given, it takes
+#'   precedence over other parameters.
+#' @param check_first Logical, defaults to `TRUE`. If `TRUE`, then before
+#'   executing anything on the database it checks if the given table has already
+#'   been indexed. If it has, it does nothing and returns only an informative
+#'   message.
+#' @param show_details Logical, defaults to `FALSE`. If `FALSE`, return the
+#'   function adds the index to the database, but does not return anything. If
+#'   `TRUE`, returns a data frame with more details about the index.
 #'
 #' @inheritParams tw_get_cache_table_name
 #' @inheritParams tw_get
 #'
-#' @return If `show_details` is set to FALSE, nothing, used only for its side effects (add index to caching table). If TRUE, a data frame, same as the output of `tw_check_cache_index(show_details = TRUE)`.
+#' @return If `show_details` is set to `FALSE`, nothing, used only for its side
+#'   effects (add index to caching table). If `TRUE`, a data frame, same as the
+#'   output of `tw_check_cache_index(show_details = TRUE)`.
 #' @export
 #'
 #' @examples
@@ -155,15 +181,17 @@ tw_check_cache_index <- function(table_name = NULL,
 #'
 #'   tw_index_cache_search()
 #' }
-tw_index_cache_search <- function(table_name = NULL,
-                                  check_first = TRUE,
-                                  type = "item",
-                                  show_details = FALSE,
-                                  language = tidywikidatar::tw_get_language(),
-                                  response_language = tidywikidatar::tw_get_language(),
-                                  cache = NULL,
-                                  cache_connection = NULL,
-                                  disconnect_db = TRUE) {
+tw_index_cache_search <- function(
+  table_name = NULL,
+  check_first = TRUE,
+  type = "item",
+  show_details = FALSE,
+  language = tidywikidatar::tw_get_language(),
+  response_language = tidywikidatar::tw_get_language(),
+  cache = NULL,
+  cache_connection = NULL,
+  disconnect_db = TRUE
+) {
   if (is.null(table_name)) {
     table_name <- tw_get_cache_table_name(
       type = stringr::str_c("search_", type),
@@ -172,7 +200,10 @@ tw_index_cache_search <- function(table_name = NULL,
     )
     language <- stringr::str_c(language, "_", response_language)
   } else {
-    language <- stringr::str_extract(string = table_name, "[a-z][a-z]_[a-z][a-z]$")
+    language <- stringr::str_extract(
+      string = table_name,
+      "[a-z][a-z]_[a-z][a-z]$"
+    )
   }
 
   db <- tw_connect_to_cache(
@@ -211,7 +242,8 @@ tw_index_cache_search <- function(table_name = NULL,
   driver <- db$fetch()
 
   if (inherits(x = driver, "SQLiteConnection") == FALSE) {
-    statement <- glue::glue_sql("ALTER TABLE {`table_name`} MODIFY search VARCHAR(255);",
+    statement <- glue::glue_sql(
+      "ALTER TABLE {`table_name`} MODIFY search VARCHAR(255);",
       table_name = table_name,
       .con = db_no_pool
     )
@@ -221,8 +253,8 @@ tw_index_cache_search <- function(table_name = NULL,
       statement = statement
     )
 
-
-    statement <- glue::glue_sql("ALTER TABLE {`table_name`} MODIFY id VARCHAR(50);",
+    statement <- glue::glue_sql(
+      "ALTER TABLE {`table_name`} MODIFY id VARCHAR(50);",
       table_name = table_name,
       .con = db_no_pool
     )
@@ -233,7 +265,8 @@ tw_index_cache_search <- function(table_name = NULL,
     )
   }
 
-  statement <- glue::glue_sql("CREATE INDEX search on {`table_name`} (search);",
+  statement <- glue::glue_sql(
+    "CREATE INDEX search on {`table_name`} (search);",
     table_name = table_name,
     .con = db_no_pool
   )
@@ -244,7 +277,7 @@ tw_index_cache_search <- function(table_name = NULL,
   )
 
   pool::poolReturn(db_no_pool)
-  if (show_details == TRUE) {
+  if (show_details) {
     output <- tw_check_cache_index(
       table_name = table_name,
       type = type,
@@ -272,21 +305,29 @@ tw_index_cache_search <- function(table_name = NULL,
 }
 
 
-
 #' Add index to caching table for search queries for increased speed
 #'
 #' Tested only with SQLite and MySql. May work with other drivers.
 #'
-#' To ensure smooth functioning, the search column in the cache table is transformed into a column of type `varchar` and length 255.
+#' To ensure smooth functioning, the search column in the cache table is
+#' transformed into a column of type `varchar` and length 255.
 #'
-#' @param table_name Name of the table in the database. If given, it takes precedence over other parameters.
-#' @param check_first Logical, defaults to `TRUE`. If `TRUE`, then before executing anything on the database it checks if the given table has already been indexed. If it has, it does nothing and returns only an informative message.
-#' @param show_details Logical, defaults to `FALSE`. If `FALSE`, return the function adds the index to the database, but does not return anything. If `TRUE`, returns a data frame with more details about the index.
+#' @param table_name Name of the table in the database. If given, it takes
+#'   precedence over other parameters.
+#' @param check_first Logical, defaults to `TRUE`. If `TRUE`, then before
+#'   executing anything on the database it checks if the given table has already
+#'   been indexed. If it has, it does nothing and returns only an informative
+#'   message.
+#' @param show_details Logical, defaults to `FALSE`. If `FALSE`, return the
+#'   function adds the index to the database, but does not return anything. If
+#'   `TRUE`, returns a data frame with more details about the index.
 #'
 #' @inheritParams tw_get_cache_table_name
 #' @inheritParams tw_get
 #'
-#' @return If `show_details` is set to FALSE, nothing, used only for its side effects (add index to caching table). If TRUE, a data frame, same as the output of `tw_check_cache_index(show_details = TRUE)`.
+#' @return If `show_details` is set to `FALSE`, nothing, used only for its side
+#'   effects (add index to caching table). If `TRUE`, a data frame, same as the
+#'   output of `tw_check_cache_index(show_details = TRUE)`.
 #' @export
 #'
 #' @examples
@@ -300,14 +341,16 @@ tw_index_cache_search <- function(table_name = NULL,
 #'
 #'   tw_index_cache_search()
 #' }
-tw_index_cache_item <- function(table_name = NULL,
-                                check_first = TRUE,
-                                type = "item",
-                                show_details = FALSE,
-                                language = tidywikidatar::tw_get_language(),
-                                cache = NULL,
-                                cache_connection = NULL,
-                                disconnect_db = TRUE) {
+tw_index_cache_item <- function(
+  table_name = NULL,
+  check_first = TRUE,
+  type = "item",
+  show_details = FALSE,
+  language = tidywikidatar::tw_get_language(),
+  cache = NULL,
+  cache_connection = NULL,
+  disconnect_db = TRUE
+) {
   if (is.null(table_name)) {
     table_name <- tw_get_cache_table_name(
       type = type,
@@ -340,7 +383,9 @@ tw_index_cache_item <- function(table_name = NULL,
     )
 
     if (check) {
-      cli::cli_alert_info("The table {.code {table_name}} is already indexed. No action taken. Set `check` to FALSE to ignore this check.")
+      cli::cli_alert_info(
+        "The table {.code {table_name}} is already indexed. No action taken. Set `check` to FALSE to ignore this check."
+      )
       return(invisible(NULL))
     }
   }
@@ -350,7 +395,8 @@ tw_index_cache_item <- function(table_name = NULL,
   driver <- db$fetch()
 
   if (inherits(x = driver, "SQLiteConnection") == FALSE) {
-    statement <- glue::glue_sql("ALTER TABLE {`table_name`} MODIFY id VARCHAR(50);",
+    statement <- glue::glue_sql(
+      "ALTER TABLE {`table_name`} MODIFY id VARCHAR(50);",
       table_name = table_name,
       .con = db_no_pool
     )
@@ -360,8 +406,8 @@ tw_index_cache_item <- function(table_name = NULL,
       statement = statement
     )
 
-
-    statement <- glue::glue_sql("ALTER TABLE {`table_name`} MODIFY property VARCHAR(50);",
+    statement <- glue::glue_sql(
+      "ALTER TABLE {`table_name`} MODIFY property VARCHAR(50);",
       table_name = table_name,
       .con = db_no_pool
     )
@@ -372,7 +418,8 @@ tw_index_cache_item <- function(table_name = NULL,
     )
   }
 
-  statement <- glue::glue_sql("CREATE INDEX qid on {`table_name`} (id, property);",
+  statement <- glue::glue_sql(
+    "CREATE INDEX qid on {`table_name`} (id, property);",
     table_name = table_name,
     .con = db_no_pool
   )
@@ -384,7 +431,7 @@ tw_index_cache_item <- function(table_name = NULL,
 
   pool::poolReturn(db_no_pool)
 
-  if (show_details == TRUE) {
+  if (show_details) {
     output <- tw_check_cache_index(
       table_name = table_name,
       type = type,
