@@ -1,17 +1,23 @@
-#' Get all Wikidata Q identifiers of all Wikipedia pages (or files, or subcategories) that are members of the given category,
+#' Get all Wikidata Q identifiers of all Wikipedia pages (or files, or
+#' subcategories) that are members of the given category,
 #'
-#' @param url Full URL to a Wikipedia category page. If given, title and language can be left empty.
-#' @param category Title of a Wikipedia category page or final parts of its url. Must include "Category:", or equivalent in other languages. If given, url can be left empty, but language must be provided.
-#' @param type Defaults to "page", defines which kind of members of a category are returned. Valid values include "page", "file", and "subcat" (for sub-category). Corresponds to `cmtype`. For details, see \url{https://www.mediawiki.org/wiki/API:Categorymembers}
-#' @param language Two-letter language code used to define the Wikipedia version to use. Defaults to language set with `tw_set_language()`; if not set, "en". If url given, this can be left empty.
-#' @param cache Defaults to NULL. If given, it should be given either TRUE or FALSE. Typically set with `tw_enable_cache()` or `tw_disable_cache()`.
-#' @param overwrite_cache Logical, defaults to FALSE. If TRUE, it overwrites the table in the local sqlite database. Useful if the original Wikidata object has been updated.
-#' @param cache_connection Defaults to NULL. If NULL, and caching is enabled, `tidywikidatar` will use a local sqlite database. A custom connection to other databases can be given (see vignette `caching` for details).
-#' @param disconnect_db Defaults to TRUE. If FALSE, leaves the connection to cache open.
-#' @param wait In seconds, defaults to 1 due to time-outs with frequent queries. Time to wait between queries to the APIs. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries.
-#' @param attempts Defaults to 10. Number of times it re-attempts to reach the API before failing.
+#' @param url Full URL to a Wikipedia category page. If given, title and
+#'   language can be left empty.
+#' @param category Title of a Wikipedia category page or final parts of its url.
+#'   Must include "Category:", or equivalent in other languages. If given, url
+#'   can be left empty, but language must be provided.
+#' @param type Defaults to "page", defines which kind of members of a category
+#'   are returned. Valid values include "page", "file", and "subcat" (for
+#'   sub-category). Corresponds to `cmtype`. For details, see
+#'   \href{https://www.mediawiki.org/wiki/API:Categorymembers}{the relevant page
+#'   of the official documentation}.
+#' @param attempts Defaults to 10. Number of times it re-attempts to reach the
+#'   API before failing.
+#' @inheritParams tw_get
 #'
-#' @return A data frame (a tibble) with eight columns: `source_title_url`, `source_wikipedia_title`, `source_qid`, `wikipedia_title`, `wikipedia_id`, `qid`, `description`, and `language`.
+#' @return A data frame (a tibble) with eight columns: `source_title_url`,
+#'   `source_wikipedia_title`, `source_qid`, `wikipedia_title`, `wikipedia_id`,
+#'   `qid`, `description`, and `language`.
 #' @export
 #'
 #' @examples
@@ -28,17 +34,19 @@
 #'     type = "page"
 #'   )
 #' }
-tw_get_wikipedia_category_members <- function(url = NULL,
-                                              category = NULL,
-                                              type = "page",
-                                              language = tidywikidatar::tw_get_language(),
-                                              cache = NULL,
-                                              overwrite_cache = FALSE,
-                                              cache_connection = NULL,
-                                              disconnect_db = TRUE,
-                                              wait = 1,
-                                              attempts = 10) {
-  if (is.null(category) == TRUE & is.null(url) == FALSE) {
+tw_get_wikipedia_category_members <- function(
+  url = NULL,
+  category = NULL,
+  type = "page",
+  language = tidywikidatar::tw_get_language(),
+  cache = NULL,
+  overwrite_cache = FALSE,
+  cache_connection = NULL,
+  disconnect_db = TRUE,
+  wait = 1,
+  attempts = 10
+) {
+  if (is.null(category) & !is.null(url)) {
     language <- stringr::str_extract(
       string = url,
       pattern = "(?<=https://)[[a-z]][[a-z]](?=.wikipedia.org/)"
@@ -124,16 +132,18 @@ tw_get_wikipedia_category_members <- function(url = NULL,
 #'     type = "page"
 #'   )
 #' }
-tw_get_wikipedia_category_members_single <- function(url = NULL,
-                                                     category = NULL,
-                                                     type = "page",
-                                                     language = tidywikidatar::tw_get_language(),
-                                                     cache = NULL,
-                                                     overwrite_cache = FALSE,
-                                                     cache_connection = NULL,
-                                                     disconnect_db = TRUE,
-                                                     wait = 1,
-                                                     attempts = 10) {
+tw_get_wikipedia_category_members_single <- function(
+  url = NULL,
+  category = NULL,
+  type = "page",
+  language = tidywikidatar::tw_get_language(),
+  cache = NULL,
+  overwrite_cache = FALSE,
+  cache_connection = NULL,
+  disconnect_db = TRUE,
+  wait = 1,
+  attempts = 10
+) {
   db <- tw_connect_to_cache(
     connection = cache_connection,
     language = language,
@@ -148,7 +158,7 @@ tw_get_wikipedia_category_members_single <- function(url = NULL,
       stringr::str_remove(pattern = stringr::fixed("wiki/"))
   }
 
-  if (tw_check_cache(cache) == TRUE & overwrite_cache == FALSE) {
+  if (tw_check_cache(cache) & !overwrite_cache) {
     db_result <- tw_get_cached_wikipedia_category_members(
       category = category,
       type = type,
@@ -201,7 +211,9 @@ tw_get_wikipedia_category_members_single <- function(url = NULL,
         i = "Consider increasing the waiting time between calls with the {.arg wait} parameter or check your internet connection."
       ))
     } else if (length(api_result) == 1) {
-      cli::cli_abort("Page not found. Make sure that language parameter is consistent with the language of the input title or url.")
+      cli::cli_abort(
+        "Page not found. Make sure that language parameter is consistent with the language of the input title or url."
+      )
     } else {
       base_json <- api_result
     }
@@ -290,7 +302,7 @@ tw_get_wikipedia_category_members_single <- function(url = NULL,
         wikipedia_id = as.numeric(.data$wikipedia_id)
       )
 
-    if (tw_check_cache(cache) == TRUE) {
+    if (tw_check_cache(cache)) {
       tw_write_wikipedia_category_members_to_cache(
         df = category_df,
         type = type,
@@ -302,7 +314,6 @@ tw_get_wikipedia_category_members_single <- function(url = NULL,
     }
   }
 
-
   wikipedia_page_qid_df <- tw_get_wikipedia_page_qid(
     title = category_df$wikipedia_title,
     language = language,
@@ -315,7 +326,6 @@ tw_get_wikipedia_category_members_single <- function(url = NULL,
     attempts = attempts
   )
 
-
   tw_disconnect_from_cache(
     cache = cache,
     cache_connection = db,
@@ -327,9 +337,6 @@ tw_get_wikipedia_category_members_single <- function(url = NULL,
 }
 
 
-
-
-
 #' Gets members of Wikipedia categories from local cache
 #'
 #' Mostly used internally.
@@ -354,12 +361,14 @@ tw_get_wikipedia_category_members_single <- function(url = NULL,
 #'
 #'   df_from_cache
 #' }
-tw_get_cached_wikipedia_category_members <- function(category,
-                                                     type = "page",
-                                                     language = tidywikidatar::tw_get_language(),
-                                                     cache = NULL,
-                                                     cache_connection = NULL,
-                                                     disconnect_db = TRUE) {
+tw_get_cached_wikipedia_category_members <- function(
+  category,
+  type = "page",
+  language = tidywikidatar::tw_get_language(),
+  cache = NULL,
+  cache_connection = NULL,
+  disconnect_db = TRUE
+) {
   if (isFALSE(tw_check_cache(cache = cache))) {
     return(invisible(NULL))
   }
@@ -376,7 +385,7 @@ tw_get_cached_wikipedia_category_members <- function(category,
   )
 
   if (pool::dbExistsTable(conn = db, name = table_name) == FALSE) {
-    if (disconnect_db == TRUE) {
+    if (disconnect_db) {
       tw_disconnect_from_cache(
         cache = cache,
         cache_connection = db,
@@ -397,9 +406,8 @@ tw_get_cached_wikipedia_category_members <- function(category,
     }
   )
 
-
   if (isFALSE(db_result)) {
-    if (disconnect_db == TRUE) {
+    if (disconnect_db) {
       tw_disconnect_from_cache(
         cache = cache,
         cache_connection = db,
@@ -413,7 +421,6 @@ tw_get_cached_wikipedia_category_members <- function(category,
   cached_df <- db_result %>%
     dplyr::collect()
 
-
   tw_disconnect_from_cache(
     cache = cache,
     cache_connection = db,
@@ -454,13 +461,15 @@ tw_get_cached_wikipedia_category_members <- function(category,
 #'     language = "en"
 #'   )
 #' }
-tw_write_wikipedia_category_members_to_cache <- function(df,
-                                                         language = tidywikidatar::tw_get_language(),
-                                                         type = "page",
-                                                         cache = NULL,
-                                                         overwrite_cache = FALSE,
-                                                         cache_connection = NULL,
-                                                         disconnect_db = TRUE) {
+tw_write_wikipedia_category_members_to_cache <- function(
+  df,
+  language = tidywikidatar::tw_get_language(),
+  type = "page",
+  cache = NULL,
+  overwrite_cache = FALSE,
+  cache_connection = NULL,
+  disconnect_db = TRUE
+) {
   if (isFALSE(tw_check_cache(cache = cache))) {
     return(invisible(NULL))
   }
@@ -479,8 +488,9 @@ tw_write_wikipedia_category_members_to_cache <- function(df,
   if (pool::dbExistsTable(conn = db, name = table_name) == FALSE) {
     # do nothing: if table does not exist, previous data cannot be there
   } else {
-    if (overwrite_cache == TRUE) {
-      statement <- glue::glue_sql("DELETE FROM {`table_name`} WHERE category = {category*}",
+    if (overwrite_cache) {
+      statement <- glue::glue_sql(
+        "DELETE FROM {`table_name`} WHERE category = {category*}",
         source_title_url = unique(df$source_title_url),
         table_name = table_name,
         .con = db
@@ -492,12 +502,7 @@ tw_write_wikipedia_category_members_to_cache <- function(df,
     }
   }
 
-  pool::dbWriteTable(db,
-    name = table_name,
-    value = df,
-    append = TRUE
-  )
-
+  pool::dbWriteTable(db, name = table_name, value = df, append = TRUE)
 
   tw_disconnect_from_cache(
     cache = cache,
@@ -511,11 +516,12 @@ tw_write_wikipedia_category_members_to_cache <- function(df,
 
 #' Reset Wikipedia category members cache
 #'
-#' Removes from cache the table where data typically gathered with `tw_get_wikipedia_category_members()` are stored.
-#'
-#' @param type Defaults to "page", defines which kind of members of a category are returned. Valid values include "page", "file", and "subcat" (for sub-category). Corresponds to `cmtype`. For details, see \url{https://www.mediawiki.org/wiki/API:Categorymembers}
+#' Removes from cache the table where data typically gathered with
+#' [tw_get_wikipedia_category_members()] are stored.
 #'
 #' @inheritParams tw_reset_wikipedia_page_links_cache
+#' @inheritParams tw_get_wikipedia_category_members
+#' @inheritParams tw_reset_item_cache
 #'
 #' @return Nothing, used for its side effects.
 #' @export
@@ -524,12 +530,14 @@ tw_write_wikipedia_category_members_to_cache <- function(df,
 #' if (interactive()) {
 #'   tw_reset_wikipedia_category_members_cache()
 #' }
-tw_reset_wikipedia_category_members_cache <- function(language = tidywikidatar::tw_get_language(),
-                                                      type = "page",
-                                                      cache = NULL,
-                                                      cache_connection = NULL,
-                                                      disconnect_db = TRUE,
-                                                      ask = TRUE) {
+tw_reset_wikipedia_category_members_cache <- function(
+  language = tidywikidatar::tw_get_language(),
+  type = "page",
+  cache = NULL,
+  cache_connection = NULL,
+  disconnect_db = TRUE,
+  ask = TRUE
+) {
   db <- tw_connect_to_cache(
     connection = cache_connection,
     language = language,
@@ -545,10 +553,24 @@ tw_reset_wikipedia_category_members_cache <- function(language = tidywikidatar::
     # do nothing: if table does not exist, nothing to delete
   } else if (isFALSE(ask)) {
     pool::dbRemoveTable(conn = db, name = table_name)
-    cli::cli_inform("Wikipedia category members cache reset for language {.val {language}} completed.")
-  } else if (utils::menu(c("Yes", "No"), title = paste0("Are you sure you want to remove from cache the Wikipedia category members cache for language: ", sQuote(language), "?")) == 1) {
+    cli::cli_inform(
+      "Wikipedia category members cache reset for language {.val {language}} completed."
+    )
+  } else if (
+    utils::menu(
+      c("Yes", "No"),
+      title = paste0(
+        "Are you sure you want to remove from cache the Wikipedia category members cache for language: ",
+        sQuote(language),
+        "?"
+      )
+    ) ==
+      1
+  ) {
     pool::dbRemoveTable(conn = db, name = table_name)
-    cli::cli_inform("Wikipedia category members cache reset for language {.val {language}} completed.")
+    cli::cli_inform(
+      "Wikipedia category members cache reset for language {.val {language}} completed."
+    )
   }
 
   tw_disconnect_from_cache(
