@@ -6,14 +6,14 @@ if (interactive()) {
   tw_set_language(language = "en")
 
   tw_enable_cache()
-  tw_set_cache_folder(path = fs::path(
-    fs::path_temp(),
-    "tw_data_testing"
-  ))
+  tw_set_cache_folder(
+    path = fs::path(
+      fs::path_temp(),
+      "tw_data_testing"
+    )
+  )
   tw_create_cache_folder(ask = FALSE)
 
-
-
   testthat::test_that("tw_get_wikipedia_category_members() works with sub-categories", {
     testthat::expect_true({
       sub_category_members_df <- tw_get_wikipedia_category_members(
@@ -28,7 +28,6 @@ if (interactive()) {
     })
   })
 
-
   testthat::test_that("tw_get_wikipedia_category_members() works when category, not url is given", {
     testthat::expect_true({
       category_members_df <- tw_get_wikipedia_category_members(
